Maxp

Struct Maxp 

pub struct Maxp<'a> {
    data: FontData<'a>,
}
Fields

data: FontData<'a>

Implementations

Source

impl<'a> Maxp<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> Version16Dot16

The version: 0x00005000 for version 0.5, 0x00010000 for version 1.0.

pub fn num_glyphs(&self) -> u16

The number of glyphs in the font.

pub fn max_points(&self) -> Option<u16>

Maximum points in a non-composite glyph.

pub fn max_contours(&self) -> Option<u16>

Maximum contours in a non-composite glyph.

pub fn max_composite_points(&self) -> Option<u16>

Maximum points in a composite glyph.

pub fn max_composite_contours(&self) -> Option<u16>

Maximum contours in a composite glyph.

pub fn max_zones(&self) -> Option<u16>

1 if instructions do not use the twilight zone (Z0), or 2 if instructions do use Z0; should be set to 2 in most cases.

pub fn max_twilight_points(&self) -> Option<u16>

Maximum points used in Z0.

pub fn max_storage(&self) -> Option<u16>

Number of Storage Area locations.

pub fn max_function_defs(&self) -> Option<u16>

Number of FDEFs, equal to the highest function number + 1.

pub fn max_instruction_defs(&self) -> Option<u16>

Number of IDEFs.

pub fn max_stack_elements(&self) -> Option<u16>

Maximum stack depth across Font Program (‘fpgm’ table), CVT Program (‘prep’ table) and all glyph instructions (in the ‘glyf’ table).

pub fn max_size_of_instructions(&self) -> Option<u16>

Maximum byte count for glyph instructions.

pub fn max_component_elements(&self) -> Option<u16>

Maximum number of components referenced at “top level” for any composite glyph.

pub fn max_component_depth(&self) -> Option<u16>

Maximum levels of recursion; 1 for simple components.

pub fn version_byte_range(&self) -> Range<usize>

pub fn num_glyphs_byte_range(&self) -> Range<usize>

pub fn max_points_byte_range(&self) -> Range<usize>

pub fn max_contours_byte_range(&self) -> Range<usize>

pub fn max_composite_points_byte_range(&self) -> Range<usize>

pub fn max_composite_contours_byte_range(&self) -> Range<usize>

pub fn max_zones_byte_range(&self) -> Range<usize>

pub fn max_twilight_points_byte_range(&self) -> Range<usize>

pub fn max_storage_byte_range(&self) -> Range<usize>

pub fn max_function_defs_byte_range(&self) -> Range<usize>

pub fn max_instruction_defs_byte_range(&self) -> Range<usize>

pub fn max_stack_elements_byte_range(&self) -> Range<usize>

pub fn max_size_of_instructions_byte_range(&self) -> Range<usize>

pub fn max_component_elements_byte_range(&self) -> Range<usize>

pub fn max_component_depth_byte_range(&self) -> Range<usize>